--[[ Globals ]]--

local AddonName = ...
local Addon = LibStub('AceAddon-3.0'):GetAddon(GetAddOnDependencies(AddonName))
local KeyBound = LibStub('LibKeyBound-1.0')
local Events = Addon.Events


--[[ Button ]]--

local PetBattlActionButton = Addon:CreateClass('CheckButton', Addon.BindableButton)

do
	local unused = {}


	function PetBattlActionButton:New(id)
		return self:Restore(id) or self:Create(id)
	end

	function PetBattlActionButton:Create(i)
		local button
			if i < 4 then
				button = self:Bind(CreateFrame('CheckButton', 'Dominos_PetAction'..i, self, 'PetBattleAbilityButtonTemplate'))
				button:SetID(i)
				PetBattleAbilityButton_OnLoad(button)
			else
				button = self:Bind(CreateFrame('CheckButton', 'Dominos_PetAction'..i, self, 'PetBattleActionButtonTemplate'))
				button:SetID(i)
			end
			
			button.icon = button.Icon
			
			if i == 4 then
				if not button.scriptsSet then
					PetBattleActionButton_Initialize(button, LE_BATTLE_PET_ACTION_SWITCH_PET);
					button.Icon:SetTexture('Interface\\Icons\\INV_Pet_SwapPet');
					button:SetScript('OnClick', function(self)
						StaticPopup_Hide('PET_BATTLE_FORFEIT',nil);
						PetBattleFrame_PetSelectionFrameUpdateVisible(true);
                	end)
                	button:SetScript('OnEnter', function(self)
						GameTooltip:SetOwner(self, 'ANCHOR_RIGHT');
						GameTooltip:SetText(SWITCH_PET, 1, 1, 1, true);
						GameTooltip:AddLine(SWITCH_PET_DESCRIPTION, nil, nil, nil, true);
						GameTooltip:Show();
					end)
					button:SetScript('OnLeave', GameTooltip_Hide)
					PetBattleActionButton_Initialize(button, LE_BATTLE_PET_ACTION_SWITCH_PET);
				end
			end
			if i == 5 then
				if not button.scriptsSet then
					button.scriptsSet = true
					PetBattleActionButton_Initialize(button, LE_BATTLE_PET_ACTION_TRAP);
					button.Icon:SetTexture('Interface\\Icons\\INV_Pet_PetTrap');
					button:SetScript('OnShow', PetBattleCatchButton_OnShow)
					button:SetScript('OnEnter', PetBattleCatchButton_OnEnter)
					button:SetScript('OnLeave', GameTooltip_Hide)
					button:SetScript('OnClick', PetBattleCatchButton_OnClick)
					PetBattleActionButton_Initialize(button, LE_BATTLE_PET_ACTION_TRAP);
				end
			end

			if i == 6 then
				if not button.scriptsSet then
					button.scriptsSet = true
					button.Icon:SetTexture('Interface\\Icons\\INV_Pet_ExitBattle');
					button:SetScript('OnClick', PetBattleForfeitButton_OnClick)
                	button:SetScript('OnEnter', function(self)
						GameTooltip:SetOwner(self, 'ANCHOR_RIGHT');
						GameTooltip:SetText(PET_BATTLE_FORFEIT, 1, 1, 1, true);
						GameTooltip:AddLine(PET_BATTLE_FORFEIT_DESCRIPTION, nil, nil, nil, true);
						GameTooltip:Show();
					end)
					button:SetScript('OnLeave', GameTooltip_Hide)
					PetBattleActionButton_Initialize(button, PET_BATTLE_FORFEIT);
				end
			end


		if button then
			Addon:GetModule('ButtonThemer'):Register(button, 'Battle Bar')
		end

		return button
	end

	function PetBattlActionButton:Restore(id)
		local button = unused[id]

		if button then
			unused[id] = nil
			button:Show()

			return button
		end
	end

	function PetBattlActionButton:Free()
		unused[self:GetID()] = self

		self:SetParent(nil)
		self:Hide()
	end
end


--[[ Bar ]]--

local PetBattlBar = Addon:CreateClass('Frame', Addon.ButtonBar)
PetBattlBar.master = Addon
_G[...] = PetBattlBar
do
	function PetBattlBar:New()
		local frame = PetBattlBar.proto.New(self, 'battle')
		frame.header:SetAttribute('updateShown', [[
			local isPetBattleUIShown = self:GetAttribute('state-petbattleui') and true or false
			local stateAlpha = tonumber(displayState)
			if self:GetAttribute('state-alpha') ~= stateAlpha then
				self:SetAttribute('state-alpha', stateAlpha)
			end
			if isPetBattleUIShown then
				self:Show()
				return
			end
			local displayState = self:GetAttribute('state-display')
			if displayState == 'hide' then
				if self:GetAttribute('state-alpha') then
					self:SetAttribute('state-alpha', nil)
				end
				self:Hide()
				return
			end
			self:Hide()
		]])
		frame.header:SetAttribute('state-showinpetbattleui', nil)
		local oldLayout = frame.Layout
		function frame:Layout()
			oldLayout(frame)
			frame:UpdateComponents()
		end
		frame:Layout()
		return frame
	end

	function PetBattlBar:GetDefaults()
		return {
			point = 'BOTTOM',
			spacing = 0,
			x = 0,
			y = 0,
		}
	end

	function PetBattlBar:NumButtons()
		return 6
	end

	function PetBattlBar:UpdateButtons()
		for i, button in pairs(self.buttons) do
			if i < 4 then
				PetBattleAbilityButton_UpdateIcons(button)
			end
			PetBattleActionButton_UpdateState(button)
		end
	end

	function PetBattlBar:GetButton(index)
		return PetBattlActionButton:New(index)
	end
end


