local bar = _G[...]
local modName = ...

local component = bar:NewComponent('turn timer', 'Frame')

function component:New(parent)
	local name = ('%s_TurnTimer'):format(modName)
	if _G[name] then
		return _G[name]
	end
	local bar = self:Bind(PetBattleFrame.BottomFrame.TurnTimer)
	bar.owner = parent
	bar:SetParent(parent.header)
	bar:EnableMouse(false)
	bar:Show()
	bar:ClearAllPoints()
	
	return bar
end

component.defaults = {
	scale = 90,
	x = 0,
	y = 27,
	anchor = 'Top',
	enable = true,
	alpha = 100,
	textureName = 'Raid',
	texturePath = 'Interface\\RaidFrame\\Raid-Bar-Hp-Fill',
}

function component:Layout()
	local sets = self.sets
	if sets.enable ~= true then
		self:Hide()
		self.noUpdate = true
		return
	else
		self:Show()
		self.noUpdate = nil
	end
	local sets = self.sets
	self:Reposition()
	self:Rescale()
	
	self:SetAlpha(sets.alpha/100)


	self.Bar:SetTexture(self:GetMediaPath('statusbar', self.sets.textureName) or self.sets.texturePath)
end

function component:Rescale()
	self:SetScale(self.sets.scale/100)
end

function component:Reposition()
	self:ClearAllPoints()
	local x = self.sets.x/(self.sets.scale/100)
	local y = self.sets.y/(self.sets.scale/100)
	self:SetPoint(self.sets.anchor, self:GetParent(), x, y)
end

function component:GetMediaPath(kind, fileName)
	if bar.lib then
		self.sets.texturePath = bar.lib and bar.lib:Fetch(kind, fileName)
	end
	return (bar.lib and bar.lib:Fetch(kind, fileName))
end

local options = {
	{
		name = 'Anchor',
		kind = 'Menu',
		key = 'anchor',
		table = {
			'TopLeft',
			'Top',
			'TopRight',
			'Right',
			'BottomRight',
			'Bottom',
			'BottomLeft',
			'Left',
			'Center',
		},
	},

	{
		name = 'Opacity',
		kind = 'Slider',
		key = 'alpha',
		min = 0,
		max = 100,
	},
	{
		name = 'X Offset',
		kind = 'Slider',
		key = 'x',
		min = -400,
		max = 400,
	},
	{
		name = 'Y Offset',
		kind = 'Slider',
		key = 'y',
		min = -400,
		max = 400,
	},
	{
		name = 'Scale',
		kind = 'Slider',
		key = 'scale',
		min = 25,
		max = 250,
	},	
	{
		name = 'Texture',
		kind = 'Media',
		key = 'textureName',
		mediaType = 'StatusBar',
		handler = 'timer',
	},
}

function component:CreateMenu(menu)
	return bar.Menu.NewPanel(menu, 'Turn Timer', options)
end
